@@ -2,7 +2,7 @@ from os import path
 import re
 from typing import Any, List, Literal, Tuple
 import argparse
-from platform import system
+from .mod import ModArg, RepoTypes
 
 _app_name = __package__.replace("_", "-")
 
@@ -19,7 +19,6 @@ def _is_dir(dir: str) -> str:
 
 class Config:
     def __init__(self):
-        self._os = system()
         self._set_default_values()
         self._parse_args()
         self.app_name: str = _app_name
@@ -31,7 +30,7 @@ class Config:
         self.beta: bool
         self.alpha: bool
         self.action: Literal["install", "update"]
-        self.mods: List[Tuple[str, str, str]]
+        self.mods: List[ModArg]
 
     def _parse_args(self):
         # Get arguments first to get verbosity before we get everything else
@@ -41,8 +40,8 @@ class Config:
 
         parser.add_argument(
             "action",
-            choices=["update", "configure", "list"],
-            help="Update, configure, or list mods",
+            choices=["install", "update", "configure", "list"],
+            help="Install, update, configure, or list mods",
         )
         parser.add_argument(
             "mods",
@@ -86,7 +85,7 @@ class Config:
         parser.add_argument(
             "--pretend",
             action="store_true",
-            help="Only pretend to install/update/configure. Does not change anything",
+            help="Only pretend to update/configure. Does not change anything",
         )
 
         _args = parser.parse_args()
@@ -116,7 +115,7 @@ class Config:
             self.beta = True
 
         # Process mods
-        self.mods: List[Tuple[str, str, str]] = []
+        self.mods = []
 
         for mod_arg in args.mods:
             match = re.match(r"(?:(.+):)?([\w-]+)(?:=(.+))?", mod_arg)
@@ -125,8 +124,24 @@ class Config:
                 print(f"{_red_color}Invalid mod syntax: {mod_arg}{_no_color}")
                 exit(1)
 
-            repo_type, mod_id, repo_alias = match.groups()
-            self.mods.append((repo_type, mod_id, repo_alias))
+            repo_type_name, mod_id, repo_alias = match.groups()
+            if repo_type_name and len(repo_type_name) > 0:
+                try:
+                    repo_type = RepoTypes[repo_type_name.lower()]
+                except KeyError:
+                    print(f"{_red_color}No site named {repo_type_name}{_no_color}")
+                    print(f"Valid names are:")
+                    for enum in RepoTypes:
+                        print(f"{enum.value}")
+
+                    exit(1)
+            else:
+                repo_type = RepoTypes.unknown
+
+            if not repo_alias:
+                repo_alias = mod_id
+
+            self.mods.append(ModArg(repo_type, mod_id, repo_alias))
 
     def _set_default_values(self):
         """Set default values for variables"""
